#
# spec file for package python-graphviz
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python3-graphviz
Version:        0.14.1
Release:        150400.6.69
Summary:        Python interface for Graphviz
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/xflr6/graphviz
Source:         https://files.pythonhosted.org/packages/source/g/graphviz/graphviz-%{version}.zip
BuildRequires:  %{python_module mock >= 2}
BuildRequires:  %{python_module pytest >= 3.4}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock >= 1.8}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  noto-sans-fonts
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
BuildRequires:  w3m
BuildRequires:  xdg-utils
Requires:       graphviz
Recommends:     xdg-utils
BuildArch:      noarch
%python_subpackages

%description
This package facilitates the creation and rendering of graph descriptions in
the DOT language of the Graphviz graph drawing software from Python.

It supports creating a graph object, assembling the graph by adding nodes and
edges, and retrieving its DOT source code string, saving the source code to a
file and rendering it with the Graphviz installation.

Using the view option/method, the resulting (PDF, PNG, SVG, etc.) file can be
inspected with its default application. Graphs can also be rendered and
displayed within IPython notebooks.

%prep
%setup -q -n graphviz-%{version}

# Fix wrong-file-end-of-line-encoding
dos2unix CHANGES.txt LICENSE.txt README.rst docs/*.rst

# Remove hardcoded pytest version
sed -i -e '/minversion/d' setup.cfg

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt README.rst
%{python_sitelib}/graphviz
%{python_sitelib}/graphviz-%{version}-py*.egg-info

%changelog
* Wed Feb  9 2022 yfjiang@suse.com
- Add noto-sans-fonts as BuildRequires to make the test suite work
  with pango 1.50.
* Thu Aug  6 2020 dmueller@suse.com
- update to 0.14.1
  * Document the colon-separated ``node[:port[:compass]]`` format used for ``tail``
  and ``head`` points in the ``edge()``- and ``edges()``-methods'
  * Improve handling of escaped quotes (``\"``). Different from other layout engine
  escapes sequences such as ``\l`` and ``\N`` (which are passed on as is by
  default), there is no use case for backslash-escaping a literal quote character
  because escaping of quotes is done by this library. Therefore, a
  backslash-escaped quote (e.g. in ``label='\\"'``) is now treated the same as a
  plain unescaped quote, i.e. both ``label='"'`` and ``label='\\"'`` produce
  the same DOT source ``[label="\""]`` (a label that renders as a literal quote).
  Before this change, use of ``'\\"'`` could break the quoting mechanism creating
  invalid or unintended DOT, possibly leading to syntax errors from the rendering
  process.
* Sun Nov 24 2019 arun@gmx.de
- update to version 0.13.2:
  * Fix missing support for four-part versions in
    "graphviz.version()".
- changes from version 0.13.1:
  * Tag Python 3.8 support.
  * Fix quoting for non-ASCII numerals.
* Thu Sep 12 2019 tchvatal@suse.com
- Update to 0.13:
  * Fix missing escaping of backslashes, e.g. in labels
  * Add basic debug logging via the stdlib ``logging`` module.
  * Add ``escape()`` function (resembling ``re.escape()``)
  * Add explicit support for layout engine escape sequences
* Sat Aug  3 2019 arun@gmx.de
- update to version 0.11.1:
  * Include "stderr" in "str()" of raised
    "subprocess.CalledProcessError".
* Sat Jun 15 2019 arun@gmx.de
- specfile:
  * be more specific i %%files section
- update to version 0.11:
  * Add "quiet" argument to ".render()" and ".pipe()" methods of
    "Graph", "Digraph", and "Source" objects, allowing to suppress
    "stderr" of the layout subprocess (parity with stand-alone
    "render()" and "pipe()" functions).
  * The rendering process for "render()" methods and stand-alone
    function is now started from the directory of the rendered dot
    source file. This allows to render graph descriptions that use
    relative paths inline (e.g. for referring to image files to be
    included) by using paths relative to the source file
    location. Previously, such relative paths would need to be given
    relative to the directory from which "render()" was started, so
    this change is backwards incompatible for code that relied on the
    previous behaviour.
  * Drop Python 3.4 support.
* Tue Apr 23 2019 tbechtold@suse.com
- Add minimal needed versions to BuildRequires
  Build fails with older python-pytest-mock versions so add the
  needed checks to avoid that
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Nov 14 2018 tchvatal@suse.com
- Update to 0.10.1:
  * python 3.7 support
  * Various fixes
* Sat Jan  6 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.8.2:
  * Add nohtml() to support labels of the form '<...>' (disabling
    their default treatment as HTML strings).
  * Make default utf-8 encoding more visible.
  * Set encoding = locale.getpreferredencoding() when encoding
    argument/property is set to None explicitly (follow stdlib io.open
    behaviour).
* Wed Nov 15 2017 jengelh@inai.de
- Replace imperatives in description.
* Wed Nov 15 2017 mimi.vx@gmail.com
- update to 0.8.1
  * please see long list of changes in
    https://github.com/xflr6/graphviz/blob/d7149d507ea6c345ac20f5d6d7e14bc3f162114c/CHANGES
* Fri Apr 14 2017 toddrme2178@gmail.com
- Initial singlespec version
